pub(crate) enum RemoteSlot {
Unknown,
Known(ItemStack),
Hashed(HashedStack),
}Expand description
What the server believes the client is showing in one slot.
Variants
Unknown
We don’t know what the client has.
Known(ItemStack)
We know the exact ItemStack the client should have.
Hashed(HashedStack)
The client reported a hash of its own perception.
Implementations
Sourceimpl RemoteSlot
impl RemoteSlot