fn hashed_stack_matches(hash: &HashedStack, item: &ItemStack) -> boolExpand description
Checks if a hashed stack matches the given ItemStack.
fn hashed_stack_matches(hash: &HashedStack, item: &ItemStack) -> boolChecks if a hashed stack matches the given ItemStack.