fn validate_component_hashes(
hashed: &HashedPatchMap,
patch: &DataComponentPatch,
) -> boolExpand description
Validates that the hashed component patch matches the local patch.
fn validate_component_hashes(
hashed: &HashedPatchMap,
patch: &DataComponentPatch,
) -> boolValidates that the hashed component patch matches the local patch.